@@ -817,6 +817,13 @@ gpgrt_free (void *a)
     _gpgrt_free (a);
 }
 
+void
+gpgrt_wipememory (void *ptr, size_t len)
+{
+  if (ptr && len)
+    _gpgrt_wipememory (ptr, len);
+}
+
 char *
 gpgrt_getenv (const char *name)
 {
@@ -847,6 +854,12 @@ gpgrt_getcwd (void)
   return _gpgrt_getcwd ();
 }
 
+gpg_err_code_t
+gpgrt_access (const char *fname, int mode)
+{
+  return _gpgrt_access (fname, mode);
+}
+
 
 
 gpgrt_b64state_t
@@ -1096,19 +1109,22 @@ gpgrt_make_pipe (int filedes[2], estream_t *r_fp, int direction, int nonblock)
 
 gpg_err_code_t
 gpgrt_spawn_process (const char *pgmname, const char *argv[],
-                     int *except, void (*preexec)(void), unsigned int flags,
+                     int *except, unsigned int flags,
                      estream_t *r_infp, estream_t *r_outfp, estream_t *r_errfp,
-                     pid_t *pid)
+                     gpgrt_process_t *r_process_id)
 {
-  return _gpgrt_spawn_process (pgmname, argv, except, preexec, flags,
-                               r_infp, r_outfp, r_errfp, pid);
+  return _gpgrt_spawn_process (pgmname, argv, except, flags,
+                               r_infp, r_outfp, r_errfp, r_process_id);
 }
 
 gpg_err_code_t
 gpgrt_spawn_process_fd (const char *pgmname, const char *argv[],
-                        int infd, int outfd, int errfd, pid_t *pid)
+                        int infd, int outfd, int errfd,
+                        int (*spawn_cb)(void *),
+                        void *spawn_cb_arg, gpgrt_process_t *r_process_id)
 {
-  return _gpgrt_spawn_process_fd (pgmname, argv, infd, outfd, errfd, pid);
+  return _gpgrt_spawn_process_fd (pgmname, argv, infd, outfd, errfd,
+                                  spawn_cb, spawn_cb_arg, r_process_id);
 }
 
 gpg_err_code_t
@@ -1119,28 +1135,36 @@ gpgrt_spawn_process_detached (const char *pgmname, const char *argv[],
 }
 
 gpg_err_code_t
-gpgrt_wait_process (const char *pgmname, pid_t pid, int hang, int *r_exitcode)
+gpgrt_wait_process (const char *pgmname, gpgrt_process_t process_id, int hang,
+                    int *r_exitcode)
 {
-  return _gpgrt_wait_process (pgmname, pid, hang, r_exitcode);
+  return _gpgrt_wait_process (pgmname, process_id, hang, r_exitcode);
 }
 
 gpg_err_code_t
-gpgrt_wait_processes (const char **pgmnames, pid_t *pids,
+gpgrt_wait_processes (const char **pgmnames, gpgrt_process_t *process_ids,
                       size_t count, int hang, int *r_exitcodes)
 {
-  return _gpgrt_wait_processes (pgmnames, pids, count, hang, r_exitcodes);
+  return _gpgrt_wait_processes (pgmnames, process_ids, count, hang,
+                                r_exitcodes);
 }
 
 void
-gpgrt_kill_process (pid_t pid)
+gpgrt_kill_process (gpgrt_process_t process_id)
 {
-  _gpgrt_kill_process (pid);
+  _gpgrt_kill_process (process_id);
 }
 
 void
-gpgrt_release_process (pid_t pid)
+gpgrt_release_process (gpgrt_process_t process_id)
 {
-  _gpgrt_release_process (pid);
+  _gpgrt_release_process (process_id);
+}
+
+void
+gpgrt_close_all_fds (int from, int *keep_fds)
+{
+  _gpgrt_close_all_fds (from, keep_fds);
 }
 #endif /*0*/
 
@@ -1235,6 +1259,31 @@ gpgrt_absfnameconcat (const char *first, ... )
  * specific function despite that they are technically not needed.  */
 #ifdef HAVE_W32_SYSTEM
 
+void
+gpgrt_free_wchar (wchar_t *wstring)
+{
+  if (wstring)
+    _gpgrt_free_wchar (wstring);
+}
+
+wchar_t *
+gpgrt_fname_to_wchar (const char *fname)
+{
+  return _gpgrt_fname_to_wchar (fname);
+}
+
+wchar_t *
+gpgrt_utf8_to_wchar (const char *string)
+{
+  return _gpgrt_utf8_to_wchar (string);
+}
+
+char *
+gpgrt_wchar_to_utf8 (const wchar_t *string)
+{
+  return _gpgrt_wchar_to_utf8 (string, (size_t)(-1));
+}
+
 char *
 gpgrt_w32_reg_query_string (const char *root, const char *dir, const char *name)
 {
